KeckMonth enum

Inheritance
Available extensions

Values

january → const KeckMonth
const KeckMonth(1, 'Januar')
february → const KeckMonth
const KeckMonth(2, 'Februar')
march → const KeckMonth
const KeckMonth(3, 'März')
april → const KeckMonth
const KeckMonth(4, 'April')
may → const KeckMonth
const KeckMonth(5, 'Mai')
june → const KeckMonth
const KeckMonth(6, 'Juni')
july → const KeckMonth
const KeckMonth(7, 'Juli')
august → const KeckMonth
const KeckMonth(8, 'August')
september → const KeckMonth
const KeckMonth(9, 'September')
october → const KeckMonth
const KeckMonth(10, 'Oktober')
november → const KeckMonth
const KeckMonth(11, 'November')
december → const KeckMonth
const KeckMonth(12, 'Dezember')

Properties

germanName String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeckMonth>
A constant List of the values in this enum, in order of their declaration.