KeckPaymentMethod enum

Inheritance
Available extensions

Values

cash → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Barzahlung')
creditCard → const KeckPaymentMethod
const KeckPaymentMethod(true, 'Kartenzahlung')
online → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Onlinezahlung')
uberApp → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Uber App')
uberCash → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Uber Cash')
uberCard → const KeckPaymentMethod
const KeckPaymentMethod(true, 'Uber Card')
boltApp → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Bolt App')
boltCash → const KeckPaymentMethod
const KeckPaymentMethod(false, 'Bolt Cash')
boltCard → const KeckPaymentMethod
const KeckPaymentMethod(true, 'Bolt Card')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Deutsches Anzeige-Label fuer die Zahlungsart-Zeile auf dem Beleg (Druck + KeckReceiptWidget). Muss 1:1 mit dem Backend-Mapping paymentMethodToString (functions/helper.js) uebereinstimmen.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
needsCreditCard bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeckPaymentMethod>
A constant List of the values in this enum, in order of their declaration.