HpsCodeEffect enum
Wie ein Ergebniscode den Ausgang eines Vorgangs bestimmt.
Values
- conclusive → const HpsCodeEffect
-
Der Code schreibt den Ausgang fest:
'0'genehmigt, jeder andere abgelehnt (bei einer Aufhebung sinngemaess, sieheHpsPayments.cancel). - noStatement → const HpsCodeEffect
-
Gemessen oder dokumentiert, aber ausdruecklich KEINE Aussage ueber den Vorgang (
9027,9900,100011) -- ein Grund weiterzuklaeren. - hostUncertain → const HpsCodeEffect
-
Der Host war beteiligt, das Terminal storniert nicht selbst -- ob belastet wurde, weiss das Terminal nicht. Ein Grund weiterzuklaeren, aber ohne dass ein spaeteres
9027daraus "nichts belastet" machen darf.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HpsCodeEffect> - A constant List of the values in this enum, in order of their declaration.