HpsCodeSource enum

Woher die Bedeutung eines Codes stammt.

Inheritance
Available extensions

Values

measured → const HpsCodeSource

Am Geraet gemessen (siehe doc/kartenzahlung.md).

documented → const HpsCodeSource

Aus der Antwortcodeliste von hobex (erhalten 11.09.2026).

measuredAndDocumented → const HpsCodeSource

Beides: gemessen und von hobex bestaetigt.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HpsCodeSource>
A constant List of the values in this enum, in order of their declaration.