HpsConnectionException class

Thrown when the HPS could not be reached at all (socket error, timeout, connection refused, …).

Inheritance

Constructors

HpsConnectionException(Object cause)

Properties

cause Object
The underlying error (e.g. SocketException, TimeoutException).
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited