isInProgress property
bool
get
isInProgress
true when a status query reports the transaction is still running
(responseCode == null).
Implementation
bool get isInProgress => responseCode == null;
true when a status query reports the transaction is still running
(responseCode == null).
bool get isInProgress => responseCode == null;