Belegbediener class

Bediener an einem Beleg.

Constructors

Belegbediener({required String? uid, required String name})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid String?
Kann fehlen (Altbeleg, Gerätebenutzer).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited