Korbzeile class

Eine Anzeigezeile des Korbs: gebündelt (Menge × Preis) oder je Stück einzeln.

Constructors

Korbzeile({required String key, required Position position, required int menge, required int betragCents})
const

Properties

betragCents int
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
menge int
final
position Position
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited