Mengenvorgabe class

Constructors

Mengenvorgabe({required Mengenregel regel, required bool fragen, required int stellen})
const

Properties

fragen bool
Die Kasse fragt beim Antippen nach der Menge (Wurst nach Gewicht: ja; Semmel: nein).
final
hashCode int
The hash code for this object.
no setterinherited
regel Mengenregel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stellen int
Nachkommastellen bei Mengenregel.dezimal.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited