BelegBlatt class

Constructors

BelegBlatt({required int zeichen, required List<BlattBlock> bloecke})
const

Properties

bloecke List<BlattBlock>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zeichen int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited