LogoStufe enum

Inheritance
Available extensions

Values

s → const LogoStufe
const LogoStufe('S', 0.42, 5)
m → const LogoStufe
const LogoStufe('M', 0.62, 8)
l → const LogoStufe
const LogoStufe('L', 0.8, 12)
xl → const LogoStufe
const LogoStufe('XL', 0.94, 16)

Properties

breiteAnteil double
final
hashCode int
The hash code for this object.
no setterinherited
hoeheZeilen int
final
index int
A numeric identifier for the enumerated value.
no setterinherited
kuerzel String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ausKuerzel(String? kuerzel) LogoStufe
Die Einstellung logoSkala des Betriebs; fehlt sie oder ist sie unbekannt, gilt M.

Constants

values → const List<LogoStufe>
A constant List of the values in this enum, in order of their declaration.