BelegSpalte class

Constructors

BelegSpalte({required String text, required int width, BelegAlign align = BelegAlign.left})
const

Properties

align BelegAlign
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
width int
Zwölftel-Anteil der Breite (1..12).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited