KeckCustomer class

Constructors

KeckCustomer({required String id, required String name, required String? email, required String? phoneNumber, required KeckCustomerAddress address, KeckSepaInfo? sepaInfo, String? vatNumber})
KeckCustomer.fromJson(Map<String, dynamic> json)
factory

Properties

address KeckCustomerAddress
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sepaInfo KeckSepaInfo?
final
vatNumber String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited