KeckCustomerAddress class

Constructors

KeckCustomerAddress({required String country, required String city, required String street, required String streetNumber, required String zip})
KeckCustomerAddress.fromJson(Map<String, dynamic> json)
factory

Properties

city String
getter/setter pair
country String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
street String
getter/setter pair
streetNumber String
getter/setter pair
zip String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited