KeckInvoice class

Constructors

KeckInvoice({required String invoiceNumber, required DateTime invoiceDate, required DateTime serviceDateStart, DateTime? serviceDateEnd, required bool vatIncluded, required bool isTaxFree, required KeckInvoicePaymentMethode paymentMethod, required String company, required String customerName, required String customerPhone, required String customerAddressStreetName, required String customerAddressStreetNumber, required String customerAddressCountryCode, required String customerAddressZIP, required String customerAddressCity, int? payUntil, required String downloadUrl})
KeckInvoice.fromJson(Map<String, dynamic> json)
factory

Properties

company String
final
customerAddressCity String
final
customerAddressCountryCode String
final
customerAddressStreetName String
final
customerAddressStreetNumber String
final
customerAddressZIP String
final
customerName String
final
customerPhone String
final
downloadUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invoiceDate DateTime
final
invoiceNumber String
final
isTaxFree bool
final
paymentMethod KeckInvoicePaymentMethode
final
payUntil int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceDateEnd DateTime?
final
serviceDateStart DateTime
final
vatIncluded bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited