LogoRaster class

Constructors

LogoRaster({required int breite, required int hoehe, required Uint8List punkte})
const

Properties

breite int
final
hashCode int
The hash code for this object.
no setterinherited
hoehe int
final
punkte Uint8List
punkte[y * breite + x], 1 = schwarz.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alsRasterImage() RasterImage
Als deckendes Schwarz-Weiss-Bild fuer den Druck-Stack (GS v 0, myPOS-PNG).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited