DruckLogo class

Firmenlogo fuer den Druck: Stufe, Pixelmass des Originals und das fertige Rasterbild aus logoRaster (Zwilling von DruckLogo im npm-Paket).

Constructors

DruckLogo({required LogoStufe stufe, required int pxBreite, required int pxHoehe, required LogoRaster raster})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pxBreite int
final
pxHoehe int
final
raster LogoRaster
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stufe LogoStufe
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited