PrintPaper class

Constructors

PrintPaper({required KeckPaperSize paperSize})

Properties

bytes List<Uint8List>
getter/setter pair
commands List<Map<String, dynamic>>
final
generator → Generator
final
hashCode int
The hash code for this object.
no setterinherited
paperSize KeckPaperSize
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBase64Image(String base64, {PosAlign align = PosAlign.center}) → void
addBytes(Uint8List byte) → void
addCut() → void
addDoubleText(String leftValue, String rightValue, {dynamic leftWidth = 6, dynamic rightWidth = 6}) → void
addFeed({int lines = 1}) → void
addFullHorizontalLine({String ch = '-'}) → void
addImage(Image image, {PosAlign align = PosAlign.center}) → void
addQrCode(String data, {QRSize size = QRSize.size6}) → void
addReverseFeed({int lines = 1}) → void
addText(String text, {PosStyles styles = const PosStyles()}) → void
addUint8ListImage(Uint8List image, {PosAlign align = PosAlign.center}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
setKeckReceipt(KasseneckReceipt receipt, {bool qrAsImage = false}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited