ReportMonth class

Constructors

ReportMonth(KeckMonth month, int year)
const
ReportMonth.fromDateTime(DateTime dateTime)
factory
ReportMonth.now()
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
month KeckMonth
final
readable String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
final

Methods

nextMonth() ReportMonth
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previousMonth() ReportMonth
toDateTime() DateTime
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override