Betrieb class

Constructors

Betrieb({required BetriebZeile zeile, required int? statusAt, required bool liveEnabled, required int? angelegtAt, required String? angelegtVia, required Map<String, dynamic> stammdaten, required bool fonEingerichtet, required int? fonVerifiedAt, required String? zugangEmail, required int? zugangEingeladenAt, required int? zugangAngenommenAt})
const
Betrieb.aus(Map<String, dynamic> k)
factory

Properties

angelegtAt int?
final
angelegtVia String?
final
avv AvvStand?
no setter
customerId String
no setter
fonEingerichtet bool
final
fonVerifiedAt int?
final
hashCode int
The hash code for this object.
no setterinherited
liveEnabled bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stammdaten Map<String, dynamic>
Die Stammdaten, so wie das Backend sie fuehrt. Bewusst als Karte und nicht als getippte Klasse: es ist eine reine Anzeige, und ein neues Feld soll hier ankommen, ohne dass das Paket nachzieht.
final
status String
no setter
statusAt int?
final
zeile BetriebZeile
final
zugangAngenommenAt int?
final
zugangEingeladenAt int?
final
zugangEmail String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited