BetriebListe class

Constructors

BetriebListe({required List<BetriebZeile> kunden, required String? cursor, required int gesamt})
const
BetriebListe.aus(Map<String, dynamic> d)
factory

Properties

cursor String?
Weiter mit diesem Wert als cursor; null heisst: das war alles.
final
gesamt int
final
hashCode int
The hash code for this object.
no setterinherited
kunden List<BetriebZeile>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited