Kasse class

Constructors

Kasse({required String cashregisterId, required String? name, required String status, required String statusText, required bool automatisch, required String? schritt, required String? schrittText, required List<String> erledigt, required List<KassenSchritt> schritte, required String? signatureId, required int versuche, required KassenFehler? letzterFehler, required int? createdAt})
const
Kasse.aus(Map<String, dynamic> k)
factory

Properties

automatisch bool
true: die Kasse geht von selbst live, sobald die Signatur bereit ist.
final
cashregisterId String
final
createdAt int?
final
erledigt List<String>
final
hashCode int
The hash code for this object.
no setterinherited
istLive bool
no setter
letzterFehler KassenFehler?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schritt String?
Der naechste offene Schritt; null, wenn die Kasse live ist.
final
schritte List<KassenSchritt>
Die Schritte, die fuer genau diese Kasse gelten (Testumgebung: weniger).
final
schrittText String?
final
signatureId String?
final
status String
entwurf, laeuft, live oder fehlgeschlagen.
final
statusText String
final
versuche int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited