KassenFehler class

Constructors

KassenFehler({required String? code, required String? meldung, required String? rc, required String? schritt, required int? at})
const

Properties

at int?
final
code String?
final
hashCode int
The hash code for this object.
no setterinherited
meldung String?
final
rc String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schritt String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited