NeueKasse class

Constructors

NeueKasse({required Kasse kasse, required bool gestartet, required bool? ok, required String? schritt, required String? grund})
const

Properties

gestartet bool
final
grund String?
signature_not_ready oder automatik_aus, wenn nicht gestartet wurde.
final
hashCode int
The hash code for this object.
no setterinherited
kasse Kasse
final
ok bool?
null heisst "nicht gelaufen" und ist etwas anderes als false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schritt String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited