PartnerFeldFehler class

Ein Feldfehler aus data.errors[] einer validation-Antwort.

Constructors

PartnerFeldFehler(String field, String message)
const

Properties

field String
Der Feldpfad, so wie er im gesendeten Betrieb steht -- verschachtelt und je Kontakt: address.land, tax_details.ustid, contacts.1.abteilung.
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited