PartnerSchluesselInfo class

Constructors

PartnerSchluesselInfo({required String? hint, required String? label, required int? createdAt, required List<String> scopes})
const
PartnerSchluesselInfo.aus(Map<String, dynamic> k)
factory

Properties

createdAt int?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
Ein Hinweis auf den Schluessel (Anfang/Ende), nie der Schluessel selbst.
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited