PartnerWebhook class

Constructors

PartnerWebhook({required String webhookId, required String url, required List<String> events, required bool aktiv, required String? beschreibung, required int? createdAt, required int? letzteZustellung, required int fehlerInFolge})
const
PartnerWebhook.aus(Map<String, dynamic> w)
factory

Properties

aktiv bool
final
beschreibung String?
final
createdAt int?
final
events List<String>
final
fehlerInFolge int
Fehlversuche in Folge -- steigt der Wert, stimmt beim Empfaenger etwas nicht.
final
hashCode int
The hash code for this object.
no setterinherited
letzteZustellung int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
webhookId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited