SignaturAntrag class
Ein Signaturantrag.
beantragt -> zugeteilt -> registriert -> bereit. registriert heisst: die
Einheit ist FinanzOnline bekannt; bereit heisst: sie darf signieren. In
der Testumgebung wird ohne registriert direkt bereit erreicht.
Constructors
-
SignaturAntrag({required String requestId, required String status, required String statusText, required String art, required String? vdaId, required String? signatureId, required SignaturFehler? fehler, required String? angefordertVia, required int? createdAt, required int? updatedAt, required List<
SignaturHistorieEintrag> historie}) -
const
-
SignaturAntrag.aus(Map<
String, dynamic> a) -
factory
Properties
- angefordertVia → String?
-
final
- art → String
-
final
- createdAt → int?
-
final
- fehler → SignaturFehler?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
historie
→ List<
SignaturHistorieEintrag> -
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureId → String?
-
final
- status → String
-
final
- statusText → String
-
final
- updatedAt → int?
-
final
- vdaId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited