SignaturStand class

Constructors

SignaturStand({required bool bereit, required String? signatureId, required String? vdaId, required List<SignaturAntrag> antraege, required bool fonVorhanden, required int? fonGeprueftAt})
const
SignaturStand.aus(Map<String, dynamic> d)
factory

Properties

antraege List<SignaturAntrag>
final
bereit bool
final
fonGeprueftAt int?
final
fonVorhanden bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureId String?
final
vdaId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited