WebhookListe class

Constructors

WebhookListe({required List<PartnerWebhook> webhooks, required List<WebhookEreignisKatalog> ereignisse})
const
WebhookListe.aus(Map<String, dynamic> d)
factory

Properties

ereignisse List<WebhookEreignisKatalog>
Der Katalog: Ereignisname und deutscher Text, so wie das Panel ihn zeigt.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhooks List<PartnerWebhook>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited