WebhookPruefung class

Das Ergebnis der Pruefung. Entweder ist sie durch -- dann steht der Zeitstempel fest --, oder sie nennt genau einen Grund.

Constructors

WebhookPruefung.nein(WebhookAblehnung? grund)
const
WebhookPruefung.ok(int zeitstempelSek)
const

Properties

grund WebhookAblehnung?
final
hashCode int
The hash code for this object.
no setterinherited
ok bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zeitstempelSek int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited