WebhookTestErgebnis class

Constructors

WebhookTestErgebnis({required String eventId, required String ereignis, required List zustellungen})
const

Properties

ereignis String
Welches Ereignis geprobt wurde -- ohne Angabe webhook.test.
final
eventId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zustellungen List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited