BarcodeType enum

1D-Barcode-Symbologien fuer GS k (Form 2). Der Wert m ist der ESC/POS-Selektor (65..73) im Befehl GS k m n <payload>.

Inheritance
Available extensions

Values

upcA → const BarcodeType
const BarcodeType(65)
upcE → const BarcodeType
const BarcodeType(66)
ean13 → const BarcodeType
const BarcodeType(67)
ean8 → const BarcodeType
const BarcodeType(68)
code39 → const BarcodeType
const BarcodeType(69)
itf → const BarcodeType
const BarcodeType(70)
codabar → const BarcodeType
const BarcodeType(71)
code93 → const BarcodeType
const BarcodeType(72)
code128 → const BarcodeType
const BarcodeType(73)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
m int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeType>
A constant List of the values in this enum, in order of their declaration.