CapabilityProfile class

Minimales Ersatz-Profil fuer den ESC/POS-Generator. Statt der 66-KB- capabilities.json nur die tatsaechlich genutzten Codepages.

Constructors

CapabilityProfile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCodePageId(String? codePage) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited