QRCode class

Constructors

QRCode(String text, QRSize size, QRCorrection level, {bool modell1 = false})
Nativer QR-Befehl GS ( k fuer text.

Properties

bytes List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxNutzlast → const int
Groesste Nutzlast, die das Laengenfeld (pL, pH) von GS ( k fassen kann.