Brand class

Eine Marke des Kontos (Logo, Farbe, Absender); id geht als brandId in issueInvoice.

Constructors

Brand({required String id, required String name, required bool isDefault})
const
Brand.fromJson(Map<String, dynamic> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isDefault bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited