CancelResult class

Constructors

CancelResult({required Invoice creditNote, required String originalId, required String? originalStatus, required int originalPaidCents, required bool replayed})
const

Properties

creditNote Invoice
final
hashCode int
The hash code for this object.
no setterinherited
originalId String
final
originalPaidCents int
Bereits auf das Original bezahlt — die Rückerstattung ist Sache des Betriebs.
final
originalStatus String?
final
replayed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited