CreditNoteRequest class
Constructors
-
CreditNoteRequest({required String idempotencyKey, required String invoiceId, required String reason, required List<
InvoiceItemInput> items, String? note}) -
const
-
CreditNoteRequest.fromJson(Map<
String, dynamic> j) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → String
-
final
- invoiceId → String
-
final
-
items
→ List<
InvoiceItemInput> -
final
- note → String?
-
final
- reason → String
-
Einer von creditNoteReasons.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited