CreditNoteResult class

Constructors

CreditNoteResult({required Invoice creditNote, required int remainingCents, required bool replayed})
const

Properties

creditNote Invoice
final
hashCode int
The hash code for this object.
no setterinherited
remainingCents int
Brutto, das nach dieser Gutschrift noch gutgeschrieben werden kann.
final
replayed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited