CreditNoteSummary class

Constructors

CreditNoteSummary({required String id, required int grossCents, String? number})
const
CreditNoteSummary.fromJson(Map<String, dynamic> j)
factory

Properties

grossCents int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
number String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited