CustomerInput class

Constructors

CustomerInput({required String type, required String name, required String country, String? legalForm, String? email, String? phone, String? street, String? houseNumber, String? zip, String? city, String? vatId, String? shortCode, bool? isAuthority, String? note, String? externalId, String? language})
const
CustomerInput.fromJson(Map<String, dynamic> j)
factory

Properties

city String?
final
country String
ISO-3166-Alpha-2, z. B. AT.
final
email String?
final
externalId String?
Kennung im eigenen System; je Konto eindeutig.
final
hashCode int
The hash code for this object.
no setterinherited
houseNumber String?
final
isAuthority bool?
final
language String?
Sprache der Rechnungen an diesen Kunden (de/en); fehlt = de.
final
legalForm String?
final
name String
final
note String?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortCode String?
Kürzel für die Rechnungsnummer; einmal gesetzt unveränderlich.
final
street String?
final
type String
private oder company.
final
vatId String?
UID-Nummer, z. B. ATU12345678.
final
zip String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited