CustomerPage class

Constructors

CustomerPage({required List<Customer> customers, String? nextCursor})
const

Properties

customers List<Customer>
final
hashCode int
The hash code for this object.
no setterinherited
nextCursor String?
null auf der letzten Seite.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited