Invoice class

Eine Rechnung oder Gutschrift. Die Felder unter „Detail" liefert nur getInvoice; in Listen und Ausstell-Antworten sind sie null.

Constructors

Invoice({required String id, required String number, required String docType, required String status, required InvoiceTotals totals, String? invoiceDate, String? dueDate, String? customerId, String? statusUrl, String? statusPassword, String? einvoiceLevel, Map<String, String> metadata = const {}, List<InvoiceItem>? items, int? paidCents, int? openCents, bool? overdue, bool? writtenOff, List<CreditNoteSummary>? creditNotes, String? relatedInvoiceId, String language = 'de', String? brandId, String? brandName})
const
Invoice.fromJson(Map<String, dynamic> j)
factory

Properties

brandId String?
Die eingefrorene Marke; null bei der Ersatzmarke ohne eigene Einrichtung.
final
brandName String?
final
creditNotes List<CreditNoteSummary>?
final
customerId String?
final
docType String
RE (Rechnung) oder GU (Gutschrift).
final
dueDate String?
final
einvoiceLevel String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
invoiceDate String?
final
items List<InvoiceItem>?
final
language String
Beim Ausstellen eingefroren; ältere Rechnungen de.
final
metadata Map<String, String>
final
number String
final
openCents int?
final
overdue bool?
final
paidCents int?
final
relatedInvoiceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
statusPassword String?
final
statusUrl String?
final
totals InvoiceTotals
final
writtenOff bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited