InvoiceItem class

Eine gespeicherte Position — wie gesendet, fehlende Angaben mit ihrem Standardwert.

Constructors

InvoiceItem({required String description, required num quantity, required String unit, required int unitPriceCents, required num vatRate, String subtitle = '', num discountPct = 0})
const
InvoiceItem.fromJson(Map<String, dynamic> j)
factory

Properties

description String
final
discountPct num
final
hashCode int
The hash code for this object.
no setterinherited
quantity num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
final
unit String
final
unitPriceCents int
final
vatRate num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited