InvoiceNotice class

Ein Hinweis an einer erfolgreichen Antwort — kein Fehler, nur etwas, das der Aufrufer wissen sollte (heute nur cash_receipt_required).

Constructors

InvoiceNotice({required String code, required String message})
const
InvoiceNotice.fromJson(Map<String, dynamic> j)
factory

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited