InvoicePayment class

Eine gebuchte Zahlung, wie die API sie zurückgibt.

Constructors

InvoicePayment({required String id, required int amountCents, String? paidAt, String? method, String? reference})
const
InvoicePayment.fromJson(Map<String, dynamic> j)
factory

Properties

amountCents int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
method String?
final
paidAt String?
final
reference String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited