InvoiceSetupGap class

Constructors

InvoiceSetupGap({required String requirement, required String message})
const
InvoiceSetupGap.fromJson(Map<String, dynamic> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
requirement String
Einer von invoiceSetupRequirements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited