PreviewResult class

Ergebnis von previewInvoice.

Constructors

PreviewResult({required InvoicePreview preview, List<InvoiceNotice> notice = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
notice List<InvoiceNotice>
Dieselben Hinweise, die das Ausstellen liefern würde; leer ohne Hinweis.
final
preview InvoicePreview
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited