RechnungTransport class

Constructors

RechnungTransport({required String apiKey, String? baseUrl, Client? httpClient, Duration? timeout})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rufen(String name, Map<String, dynamic> params) Future<Map<String, dynamic>>
Einen Aufruf mit JSON-Antwort absetzen; liefert data ohne Hülle.
rufenBinaer(String name, Map<String, dynamic> params) Future<Uint8List>
Einen Aufruf mit Binärantwort (PDF) absetzen. Im Fehlerfall antwortet der Server mit der gewohnten JSON-Hülle.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited