RecordPaymentRequest class

Eine Zahlung nachtragen. Der Schlüssel ist Pflicht: ohne ihn bucht eine Wiederholung nach einem Zeitlimit ein zweites Mal.

Constructors

RecordPaymentRequest({required String idempotencyKey, required String invoiceId, required String method, int? amountCents, String? paidAt, String? reference, bool? onSite})
const

Properties

amountCents int?
final
hashCode int
The hash code for this object.
no setterinherited
idempotencyKey String
final
invoiceId String
final
method String
final
onSite bool?
Zahlung vor Ort — siehe PaymentInput.onSite.
final
paidAt String?
final
reference String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited