RecordPaymentResult class

Ergebnis von recordInvoicePayment.

Constructors

RecordPaymentResult({required Invoice invoice, required InvoicePayment payment, required bool replayed, List<InvoiceNotice> notice = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
invoice Invoice
final
notice List<InvoiceNotice>
Hinweise zu dieser Zahlung — eine Liste wie bei issueInvoice, leer ohne Hinweis. Bis 6.20.0 ein einzelner, nullbarer InvoiceNotice.
final
payment InvoicePayment
final
replayed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited