VatRateTotal class

Summen eines USt-Satzes.

Constructors

VatRateTotal({required int rate, required int netCents, required int vatCents, int? grossCents})
const
VatRateTotal.fromJson(Map<String, dynamic> j)
Ein Server vor npm 0.22.0 schickt grossCents nicht mit; es ist per Definition Netto + USt und wird dann daraus gebildet.
factory

Properties

grossCents int
netCents + vatCents — im Brutto-Modus der vereinbarte Preis dieses Satzes.
final
hashCode int
The hash code for this object.
no setterinherited
netCents int
final
rate int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vatCents int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited