PairedRegisterDevice class

Ergebnis der Kopplung — der vollständige Ausweis dieses Geräts.

Constructors

PairedRegisterDevice({required String ownerUid, required String deviceId, required String deviceSecret, required String cashregisterId, required String companyName, required String cashregisterLabel})
const

Properties

cashregisterId String
Kasse, an die die Kopplung dieses Gerät gebunden hat.
final
cashregisterLabel String
Bezeichnung der Kasse — Anzeige, kann leer sein.
final
companyName String
Firmenname des Betriebs — Anzeige, kann leer sein.
final
deviceId String
final
deviceSecret String
Geheimnis dieses Geräts; das Backend liefert es genau einmal aus.
final
hashCode int
The hash code for this object.
no setterinherited
ownerUid String
Kunde, unter dem das Gerät hängt.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited