RegisterGeo class

Standort (freiwillig); Grundlage der Standortsperre.

Constructors

RegisterGeo({required double lat, required double lng, double? acc})
const

Properties

acc double?
Genauigkeit in Metern.
final
hashCode int
The hash code for this object.
no setterinherited
lat double
final
lng double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited