RegisterSessionsStand class
Antwort von RegisterClient.listRegisterSessionsForDevice.
Constructors
-
RegisterSessionsStand({required int licenses, required List<
RegisterSession> sessions}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- licenses → int
-
Lizenzplätze der Kasse — mindestens 1.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
RegisterSession> -
Laufende Sitzungen, älteste zuerst.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited