LogoService class

Constructors

LogoService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getLogoBytes(String? imageUrl) Uint8List?
Gibt das Bild als Uint8List für den Belegdruck zurück
Lädt das Bild nur einmal und speichert es