SumupService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkout(
{required String title, required double total, int saleItemsCount = 1, double tip = 0.0, bool skipSuccessScreen = true, bool skipFailureScreen = false, bool tipOnCardReader = false, String? customerEmail, String? customerPhone, String? foreignTransactionId}) → Future< SumupCheckoutResponse> -
init(
String affiliateKey) → Future< bool>