KeckPaperSize enum
Values
- mm58 → const KeckPaperSize
-
const KeckPaperSize(PaperSize.mm58, 32, 58, 300) - mm72 → const KeckPaperSize
-
const KeckPaperSize(PaperSize.mm72, 42, 72, 400) - mm80 → const KeckPaperSize
-
const KeckPaperSize(PaperSize.mm80, 48, 80, 500)
Properties
- defaultCharCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageWidth → int
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mm → int
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - paperSize → PaperSize
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator <(
KeckPaperSize other) → bool -
operator <=(
KeckPaperSize other) → bool -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
KeckPaperSize other) → bool -
operator >=(
KeckPaperSize other) → bool
Constants
-
values
→ const List<
KeckPaperSize> - A constant List of the values in this enum, in order of their declaration.