Die Tabelle selbst und die Abfrage darauf.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lookup(
String? code) → HpsCode? -
Der Eintrag zu
code, odernull, wenn seine Bedeutung nicht feststeht. -
reasonOf(
String? code) → HpsCodeReason? -
Der Grund zu
code; HpsCodeReason.unknown fuer einen Code, der in der Tabelle fehlt,nullohne Code.