HpsException class
Base class for all errors thrown by this package.
Note: a declined payment is not an exception — it is returned as a
TransactionResponse with isApproved == false. Exceptions represent
transport failures or non-success HTTP status codes.
- Implemented types
- Implementers
Constructors
- HpsException(String message)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited