HpsHttpException class

Thrown when the HPS responds with a non-2xx HTTP status code.

Common cases:

  • 400 — missing/invalid parameter, or transaction already cancelled/captured.
  • 403 — the requested feature is not activated for this account.
  • 404 — transaction not found, or endpoint not implemented.
  • 503 — terminal not operable.
Inheritance

Constructors

HpsHttpException(int statusCode, String message, {String? body})

Properties

body String?
The raw response body, if any.
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
The HTTP status code returned by the HPS.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited