HpsTransactionType enum
Numeric transaction type as sent in the request body of the
/api/transaction/payment route.
Values
- sale → const HpsTransactionType
-
Normal sale / authorization (purchase).
const HpsTransactionType(1) - preAuth → const HpsTransactionType
-
Pre-authorization (blocks an amount on the card).
const HpsTransactionType(2) - preAuthCancel → const HpsTransactionType
-
Cancel a former pre-authorization (releases the blocked amount).
const HpsTransactionType(7) - preAuthCapture → const HpsTransactionType
-
Capture a former pre-authorization.
const HpsTransactionType(8)
Properties
- code → int
-
The integer value expected by the HPS.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HpsTransactionType> - A constant List of the values in this enum, in order of their declaration.