Farbe class
Constructors
Properties
- b → int
-
final
- g → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- helligkeit → double
-
Relative Helligkeit nach WCAG (0 = Schwarz, 1 = Weiß).
no setter
- hex → String
-
no setter
- r → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wert → int
-
no setter
Methods
-
gemischt(
Farbe andere, double anteil) → Farbe -
Mischt zu
anderehin;anteil0 = diese Farbe, 1 = die andere. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override