Kassierstand class
Was der Kassier am Kassieren-Bildschirm eingestellt hat.
Constructors
- Kassierstand({required KeckPaymentMethod zahlungsart, int rabattCents = 0, int? gegebenCents, int trinkgeldCents = 0})
-
const
- Kassierstand.start(KasseSettingsBetrieb betrieb)
-
Startstand: die erste Zahlungsart, die der Betrieb anbietet. Ein Betrieb
ohne Bargeld darf nicht mit „Bar" vorbelegt beginnen.
factory
Properties
- gegebenCents → int?
-
Bar gegeben;
null, solange nichts getippt wurde — das ist etwas anderes als „null Euro gegeben".final - hashCode → int
-
The hash code for this object.
no setterinherited
- rabattCents → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trinkgeldCents → int
-
final
- zahlungsart → KeckPaymentMethod
-
final
Methods
-
kopie(
{KeckPaymentMethod? zahlungsart, int? rabattCents, int? gegebenCents, bool gegebenLoeschen = false, int? trinkgeldCents}) → Kassierstand -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited