BelegRaster class
Constructors
-
BelegRaster({required List<
RasterZeile> lines, required int zeichen}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
RasterZeile> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zeichen → int
-
final
Methods
-
alsText(
) → String - Klartext (eine Zeile je Rasterzeile) — für Golden-Vergleiche und Logs.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
render(
BelegLayout layout, {int? zeichen}) → BelegRaster -
Setzt das Zeilenmodell ins Raster;
zeichenfehlt → nachpaperSize(32/48).