RasterZeile class
Constructors
Properties
- art → RasterArt
-
final
- bold → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qr → String?
-
Bei
qr: die Nutzlast.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Genau N Zeichen (bei
qr: zentrierter Platzhalter).final - warnung → bool
-
Bei
banner: invers/auffällig.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited