Cashregister class
Constructors
- Cashregister({required String userId, required String id, required DateTime createTime, required String token, required String aesKey, String? signatureId, CashboxStatus? status})
-
Cashregister.fromJson(Map<
String, dynamic> json, String id, String userId) -
factory
Properties
- aesKey ↔ String
-
getter/setter pair
- createTime ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureId ↔ String?
-
getter/setter pair
- status ↔ CashboxStatus?
-
getter/setter pair
- token ↔ String
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited