PrintPaper class

Constructors

PrintPaper({required KeckPaperSize paperSize, required CapabilityProfile profile})

Properties

bytes List<Uint8List>
getter/setter pair
commands List<Map<String, dynamic>>
final
generator → Generator
final
hashCode int
The hash code for this object.
no setterinherited
myPosPaper → MyPosPaper
final
paperSize KeckPaperSize
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBase64Image(String base64, {PosAlign align = PosAlign.center}) → void
addBytes(Uint8List byte) → void
addCut() → void
addDoubleText(String leftValue, String rightValue, {int leftWidth = 6, int rightWidth = 6}) → void
addFeed({int lines = 1}) → void
addFullHorizontalLine({String ch = '-'}) → void
addImage(Image image, {PosAlign align = PosAlign.center}) → void
addQrCode(String data, {QRSize size = QRSize.size6}) → void
addQrCodeAsImage(String data, {int size = 280, bool raster = true}) Future<void>
QR als Bild. raster true → GS v 0 (imageRaster), false → ESC * (image). Welcher Befehl funktioniert, hängt vom Drucker ab — daher umschaltbar.
addReverseFeed({int lines = 1}) → void
addText(String text, {PosStyles styles = const PosStyles()}) → void
addUint8ListImage(Uint8List image, {PosAlign align = PosAlign.center}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
setKeckReceipt(KasseneckReceipt receipt, {QrPrintMode qrMode = QrPrintMode.imageRaster}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited