SumupCheckoutResponse class
Constructors
- SumupCheckoutResponse({required bool success, String? transactionCode, double? amount, String? currency, double? vatAmount, double? tipAmount, String? paymentType, String? entryMode, int? installments, String? cardType, String? cardLastDigits})
-
SumupCheckoutResponse.fromMap(Map<
String, dynamic> response) -
factory
- SumupCheckoutResponse.fromSumup(SumupPluginCheckoutResponse response)
-
factory
Properties
- amount → double?
-
final
- cardLastDigits → String?
-
final
- cardType → String?
-
final
- currency → String?
-
final
- entryMode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installments → int?
-
final
- paymentType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
- tipAmount → double?
-
final
- transactionCode → String?
-
final
- vatAmount → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited