KassenListe class
Constructors
-
KassenListe({required String customerId, required List<
Kasse> kassen, required bool signaturBereit}) -
const
-
KassenListe.aus(Map<
String, dynamic> d, String rueckfall) -
factory
Properties
- customerId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kassen
→ List<
Kasse> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signaturBereit → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited