NeuerBetrieb class
Das Ergebnis von createPartnerCustomer.
Constructors
-
NeuerBetrieb({required String customerId, required String status, required PartnerEnv env, required String firma, required String appId, required bool eingeladen, required String? sentTo, required List<
String> naechsteSchritte, required bool wiederholt}) -
const
-
NeuerBetrieb.aus(Map<
String, dynamic> d, String appIdRueckfall) -
factory
Properties
- appId → String
-
final
- customerId → String
-
final
- eingeladen → bool
-
final
- env → PartnerEnv
-
final
- firma → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
naechsteSchritte
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentTo → String?
-
Empfaenger der Einladung, maskiert -- die Adresse gibt das Backend nie
im Klartext aus.
final
- status → String
-
final
- wiederholt → bool
-
true, wenn derselbeidempotencyKeyschon einmal ankam. Dann ist dies die gespeicherte Antwort und es wurde nichts zweites angelegt.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited