PartnerInfo class
Constructors
-
PartnerInfo({required String partnerId, required String name, required String status, required bool darfZugangEinrichten, required PartnerEnv env, required List<
String> scopes, required PartnerSchluesselInfo key, required List<PartnerApp> apps}) -
const
-
PartnerInfo.aus(Map<
String, dynamic> d) -
factory
Properties
-
apps
→ List<
PartnerApp> -
final
- darfZugangEinrichten → bool
-
Darf dieser Partner fuer seine Betriebe einen Zugang zum Kundenpanel
einrichten lassen? Vorgabe
false-- die Freischaltung setzt Kasseneck je Partner. Ohne sie antworteneinladen: trueundresendPartnerCustomerInvitemitzugang_nicht_erlaubt, und es entsteht nichts.final - env → PartnerEnv
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → PartnerSchluesselInfo
-
final
- name → String
-
final
- partnerId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited