WebhookZustellung class
Constructors
- WebhookZustellung({required String deliveryId, required String webhookId, required String event, required String eventId, required String status, required int versuche, required int? letzterVersuchAt, required int? naechsterVersuchAt, required int? statusCode, required String? antwort, required int? createdAt})
-
const
-
WebhookZustellung.aus(Map<
String, dynamic> z) -
factory
Properties
- antwort → String?
-
Auszug der Antwort des Empfaengers, hoechstens 500 Zeichen.
final
- createdAt → int?
-
final
- deliveryId → String
-
final
- event → String
-
final
- eventId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- letzterVersuchAt → int?
-
final
- naechsterVersuchAt → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
offen,zugestelltoderfehlgeschlagen.final - statusCode → int?
-
final
- versuche → int
-
final
- webhookId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited