EscPosGenerator class
Methods
-
barcode(BarcodeType type, String data, {PosAlign align = PosAlign.center, int height = 100, int width = 3, BarcodeHri hri = BarcodeHri.below})
→ List<int>
-
Print a 1D barcode using GS k (Form 2, laengen-praefigiert).
-
cut({PosCutMode mode = PosCutMode.full})
→ List<int>
-
Cut the paper
-
drawer({PosDrawer pin = PosDrawer.pin2})
→ List<int>
-
Open cash drawer
-
emptyLines(int n)
→ List<int>
-
Skips
n lines
-
feed(int n)
→ List<int>
-
Skips
n lines
-
hr({String ch = '-', int? len, int linesAfter = 0})
→ List<int>
-
Print horizontal full width separator
If
len is null, then it will be defined according to the paper width
-
image(RasterImage imgSrc, {PosAlign align = PosAlign.center})
→ List<int>
-
Print an image using (ESC *) command
-
imageRaster(RasterImage image, {PosAlign align = PosAlign.center, bool highDensityHorizontal = true, bool highDensityVertical = true, PosImageFn imageFn = PosImageFn.bitImageRaster})
→ List<int>
-
Print an image using (GS v 0) obsolete command
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
qrcode(String text, {PosAlign align = PosAlign.center, QRSize size = QRSize.size4, QRCorrection cor = QRCorrection.L})
→ List<int>
-
Print a QR Code
-
reset()
→ List<int>
-
Clear the buffer and reset text styles
-
reverseFeed(int n)
→ List<int>
-
Reverse feed for
n lines (if supported by the printer)
-
row(List<PosColumn> cols)
→ List<int>
-
Print a row.
-
setGlobalCodeTable(String? codeTable)
→ List<int>
-
Set global code table which will be used instead of the default printer's code table
(even after resetting)
-
setGlobalFont(PosFontType? font, {int? maxCharsPerLine})
→ List<int>
-
Set global font which will be used instead of the default printer's font
(even after resetting)
-
setStyles(PosStyles styles)
→ List<int>
-
-
text(String text, {PosStyles styles = const PosStyles(), int linesAfter = 0, int? maxCharsPerLine})
→ List<int>
-
-
toString()
→ String
-
A string representation of this object.
inherited