Customer class
Constructors
- Customer({required String id, required String type, required String name, required String country, String? legalForm, String? email, String? phone, String? street, String? houseNumber, String? zip, String? city, String? vatId, String? shortCode, bool isAuthority = false, String? note, String? externalId, String language = 'de', String? createdAt, String? updatedAt})
-
const
-
Customer.fromJson(Map<
String, dynamic> j) -
factory
Properties
- city → String?
-
final
- country → String
-
final
- createdAt → String?
-
final
- email → String?
-
final
- externalId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- houseNumber → String?
-
final
- id → String
-
final
- isAuthority → bool
-
final
- language → String
-
Sprache der Rechnungen an diesen Kunden; fehlt =
de.final - legalForm → String?
-
final
- name → String
-
final
- note → String?
-
final
- phone → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortCode → String?
-
final
- street → String?
-
final
- type → String
-
final
- updatedAt → String?
-
final
- vatId → String?
-
final
- zip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited