EInvoiceStatus class
Wie weit eine Rechnung als E-Rechnung (EN 16931) taugt.
Constructors
-
EInvoiceStatus({required String level, List<
String> formats = const [], List<String> missing = const []}) -
const
-
EInvoiceStatus.fromJson(Map<
String, dynamic> j) -
factory
Properties
-
formats
→ List<
String> -
Die Formate, die entstehen (
UBL,Factur-X); leer beiinsufficient.final - hashCode → int
-
The hash code for this object.
no setterinherited
- level → String
-
full,partialoderinsufficient.final -
missing
→ List<
String> -
Was für eine vollständige E-Rechnung fehlt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited