InvoicePreview class
Was issueInvoice mit dieser Anfrage ausstellen würde — ohne Nummer, ohne
Dokument, ohne Zahlung (previewInvoice).
Constructors
- InvoicePreview({required String docType, required String invoiceDate, required String taxScheme, required String taxCountry, required String priceMode, required InvoiceTotals totals, String? dueDate, String? customerId, String? taxSchemeReason, String? reverseChargeReason, String language = 'de', String? brandId, String? brandName, EInvoiceStatus? einvoice})
-
const
-
InvoicePreview.fromJson(Map<
String, dynamic> j) -
factory
Properties
- brandId → String?
-
Die Marke, die die Rechnung trüge;
nullbei der Ersatzmarke.final - brandName → String?
-
final
- customerId → String?
-
final
- docType → String
-
Immer
RE— einen Probelauf gibt es nur für das Ausstellen.final - dueDate → String?
-
final
- einvoice → EInvoiceStatus?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceDate → String
-
Heutiger Wiener Tag — der Tag, den eine sofort ausgestellte Rechnung trüge.
final
- language → String
-
final
- priceMode → String
-
final
- reverseChargeReason → String?
-
Bei
domesticReverseChargeeiner ausreverseChargeReasons.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxCountry → String
-
ISO-3166-Alpha-2 des Landes, dessen Steuer gilt.
final
- taxScheme → String
-
Der abgeleitete Steuerfall (taxSchemes).
final
- taxSchemeReason → String?
-
Warum dieser Fall gilt (z. B.
customer_country_eu_with_vat_id).final - totals → InvoiceTotals
-
Die Summen, die die Rechnung ausweisen würde — wie
rechnungSummensie vorab rechnet, hier aber vom Server.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited