IssueResult class

Constructors

IssueResult({required Invoice invoice, required bool replayed})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
invoice Invoice
final
replayed bool
true, wenn die Anfrage schon einmal ausgeführt wurde.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited