Was für die Summe einer Rechnung zählt (rechnungSummen) —
InvoiceItemInput erfüllt es unverändert.
- Implementers
Constructors
- SummenPosition({required num quantity, required num unitPriceCents, required int vatRate, num? discountPct})
-
constfactory
Properties
- discountPct → num?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- quantity → num
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unitPriceCents → num
-
no setter
- vatRate → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited