KeckPrinterService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- networkPrinter → PrinterNetworkManager?
-
no setter
- paperSize ↔ KeckPaperSize
-
getter/setter pair
- profile → CapabilityProfile?
-
no setter
Static Methods
-
getBytesFromReceipt(
KasseneckReceipt receipt, KeckPaperSize paperSize, {bool qrAsImage = false}) → Future< List< Uint8List> > -
initBluetoothPrinter(
{KeckPaperSize size = KeckPaperSize.mm58}) → Future< bool> -
initWifiPrinter(
String ipAddress, KeckPaperSize size) → Future< bool> -
openCashDrawer(
) → Future -
printReceipt(
KasseneckReceipt receipt) → Future