KeckPrinterService class

Constructors

KeckPrinterService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

devicePrinter → BluetoothDevice
no setter
ipAddress String?
getter/setter pair
paperSize KeckPaperSize
getter/setter pair
port int
getter/setter pair
profile → CapabilityProfile?
no setter

Static Methods

getBytesFromReceipt(KasseneckReceipt receipt, KeckPaperSize paperSize, {QrPrintMode qrMode = QrPrintMode.imageRaster}) Future<List<Uint8List>>
getMyPosPaperFromReceipt(KasseneckReceipt receipt) Future<MyPosPaper>
initBluetoothPrinter({KeckPaperSize size = KeckPaperSize.mm58, required String printerAddress}) Future<bool>
initWifiPrinter(String ipAddress, KeckPaperSize size, {int port = 9100}) Future<bool>
openCashDrawer() Future
printReceiptBluetooth(KasseneckReceipt receipt, {QrPrintMode qrMode = QrPrintMode.imageRaster}) Future
printReceiptMypos(KasseneckReceipt receipt) Future<PrintResponse>
printReceiptWifi(KasseneckReceipt receipt) Future